{% extends "forum/_base.html" %}

{% from "macros/box.html" import m_box_menu, m_box_content %}
{% from "forum/_macros.html" import m_postattachments %}


{% block content %}
  {% call m_box_content(_("Recent conversations attachments")) %}
    {% for month, posts in grouped_posts %}
      <h2>{{ month }}</h2>

      <ul class="attachments-archives">
        {% for post in posts %}
          {{ m_postattachments(post) }}
        {% endfor %}
      </ul>
    {% else %}
      <p>{{ _("No attachment has been posted to this community yet") }}</p>
    {% endfor %}
  {% endcall %}
{% endblock %}
