@media print {
  /* things we don't to see printed */

  /* things we want to see */
  /* collapable: alway expand */
  .collapsable *[data-toggle="collapse"] {
    background-image: url("../icons/round-minus-16.png");
  }
}